# django imports
from django.http import HttpResponseRedirect
from django.shortcuts import render_to_response
from django.template import RequestContext
from django.core.urlresolvers import reverse

# lfs imports
import lfs.customer.utils
from lfs_contact.forms import ContactForm
from lfs_contact.utils import send_contact_mail


def contact_form(request, template_name="lfs/contact/contact_form.html"):
    """Displays the contact form of LFS.
    """
    if request.method == 'POST':
        form = ContactForm(data=request.POST)
        if form.is_valid():
            send_contact_mail(request, form)
            return HttpResponseRedirect(reverse("lfs_contact_form_sent"))
    else:
        customer = lfs.customer.utils.get_customer(request)

        try:
            name = customer.address.firstname + " " + customer.address.lastname
            email = customer.address.email
        except AttributeError:
            name = ""
            email = ""

        form = ContactForm(initial={"name": name, "email": email})

    return render_to_response(template_name, RequestContext(request, {
        "form": form,
    }))


def contact_form_sent(request, template_name="lfs/contact/contact_form_sent.html"):
    """Displays the page after the the contact form has been sent.
    """
    return render_to_response(template_name, RequestContext(request, {}))



# django imports
from django import forms
from django.utils.translation import ugettext_lazy as _


class ContactForm(forms.Form):
    """Simple contact form for LFS.
    """
    name = forms.CharField(label=_(u'Name'))
    email = forms.EmailField(label=_(u'E-Mail'))
    message = forms.CharField(label=_(u'Message'), widget=forms.Textarea())



# python imports
import datetime

# django imports
from django.core.mail import EmailMultiAlternatives
from django.template.loader import render_to_string
from django.template import RequestContext
from django.utils.translation import ugettext_lazy as _

# lfs imports
import lfs.core.utils


def send_contact_mail(request, form, template="lfs/mail/contact_mail.html"):
    """Sends an internal mail after a customer as submit the standard contact
    form.
    """
    shop = lfs.core.utils.get_default_shop()
    subject = _(u"New mail from %(shop)s" % {"shop": shop.name})
    from_email = request.POST.get("email")
    to = shop.get_notification_emails()
    bcc = []

    fields = []
    for field_name, field in form.fields.items():
        fields.append({
            "label": _(field.label.title()),
            "value": form.cleaned_data.get(field_name)
        })

    text = render_to_string(template, RequestContext(request, {
        "date": datetime.datetime.now(),
        "shop": shop,
        "fields": fields,
    }))

    # Add Sender header, because eg. Gmail don't like From header set to @gmail
    # but email not really sent by gmail servers.
    # If email is sent From: @gmail.com it generates the following message in our postfix
    # host gmail-smtp-in.l.google.com[74.125.136.26] said: 421-4.7.0 [xx.xx.xx.xx 15]
    # Our system has detected an unusual rate of 421-4.7.0 unsolicited mail
    # originating from your IP address. To protect our 421-4.7.0 users from
    # spam, mail sent from your IP address has been temporarily 421-4.7.0 rate
    # limited. Please visit 421-4.7.0 http://www.google.com/mail/help/bulk_mail.html
    # to review our Bulk 421 4.7.0 Email Senders Guidelines.
    headers = {
        'Sender': shop.from_email
    }

    mail = EmailMultiAlternatives(subject=subject, body="", from_email=from_email, to=to, bcc=bcc, headers=headers)
    mail.attach_alternative(text, "text/html")

    mail.send()



# django imports
from django.conf.urls import patterns, url

urlpatterns = patterns('lfs_contact.views',
    url(r'^contact$', "contact_form", name='lfs_contact_form'),
    url(r'^contact-form-sent/$', "contact_form_sent", name='lfs_contact_form_sent'),
)
